function [ N ] = Langer( Sa, Sm, Sy )
%
%  This routine computes the Langer or static safety factor
%
%    Sa = the alternating stress
%    Sm = the mean stress
%    Sy = the yield strength of the material
%

N = Sy / (Sa + Sm);

end

